@@ -1,21 +1,5 @@
-/*
-    Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
-*/
+// Copyright (C) 2024 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include "testwindow.h"
 #include "util.h"
@@ -27,6 +11,7 @@
 #include <QtCore/qfile.h>
 #include <QtCore/qstandardpaths.h>
 #include <QtWebView/qtwebviewfunctions.h>
+#include <QtWebViewQuick/private/qquickwebviewsettings_p.h>
 
 QUrl getTestFilePath(const QString &testFile)
 {
@@ -47,6 +32,8 @@ public:
     tst_QQuickWebView();
 
 private Q_SLOTS:
+    void initTestCase();
+
     void init();
     void cleanup();
 
@@ -71,6 +58,9 @@ private Q_SLOTS:
     void changeUserAgent();
     void setAndDeleteCookies();
 
+    void settings_JS_data();
+    void settings_JS();
+
 private:
     inline QQuickWebView *newWebView();
     inline QQuickWebView *webView() const;
@@ -94,9 +84,17 @@ QQuickWebView *tst_QQuickWebView::newWebView()
 {
     QObject *viewInstance = m_component->create();
     QQuickWebView *webView = qobject_cast<QQuickWebView*>(viewInstance);
+    webView->settings()->setAllowFileAccess(true);
+    webView->settings()->setLocalContentCanAccessFileUrls(true);
     return webView;
 }
 
+void tst_QQuickWebView::initTestCase()
+{
+    if (!qEnvironmentVariableIsEmpty("QEMU_LD_PREFIX"))
+        QSKIP("This test is unstable on QEMU, so it will be skipped.");
+}
+
 void tst_QQuickWebView::init()
 {
     QtWebView::initialize();
@@ -324,9 +322,8 @@ void tst_QQuickWebView::titleUpdate()
     // Load page with no title
     webView()->setUrl(getTestFilePath("basic_page2.html"));
     QVERIFY(waitForLoadSucceeded(webView()));
-#ifdef QT_WEBVIEW_WEBENGINE_BACKEND
-    // webengine emits titleChanged even if there is no title
-    // QTBUG-94151
+#if defined(QT_WEBVIEW_WEBENGINE_BACKEND) || defined(Q_OS_ANDROID)
+    // on some platforms if the page has no <title> element, then the URL is used instead
     QCOMPARE(titleSpy.size(), 1);
 #else
     QCOMPARE(titleSpy.size(), 0);
@@ -336,8 +333,12 @@ void tst_QQuickWebView::titleUpdate()
     // No titleChanged signal for failed load
     webView()->setUrl(getTestFilePath("file_that_does_not_exist.html"));
     QVERIFY(waitForLoadFailed(webView()));
+#if defined(Q_OS_ANDROID)
+    // error page with "Webpage not available"
+    QTRY_COMPARE(titleSpy.size(), 1);
+#else
     QCOMPARE(titleSpy.size(), 0);
-
+#endif
 }
 
 void tst_QQuickWebView::changeUserAgent()
@@ -356,8 +357,8 @@ void tst_QQuickWebView::changeUserAgent()
 
 void tst_QQuickWebView::setAndDeleteCookies()
 {
-    QSignalSpy cookieAddedSpy(webView(), SIGNAL(cookieAdded(const QString &, const QString &)));
-    QSignalSpy cookieRemovedSpy(webView(), SIGNAL(cookieRemoved(const QString &, const QString &)));
+    QSignalSpy cookieAddedSpy(webView(), SIGNAL(cookieAdded(QString,QString)));
+    QSignalSpy cookieRemovedSpy(webView(), SIGNAL(cookieRemoved(QString,QString)));
 
 #ifdef QT_WEBVIEW_WEBENGINE_BACKEND
     webView()->setUrl(QUrl("qrc:///cookies.html"));
@@ -407,5 +408,32 @@ void tst_QQuickWebView::setAndDeleteCookies()
     QTRY_COMPARE(cookieRemovedSpy.size(), 3);
 }
 
+void tst_QQuickWebView::settings_JS_data()
+{
+    QTest::addColumn<bool>("jsEnabled");
+    QTest::addColumn<QUrl>("testUrl");
+    QTest::addColumn<QString>("expectedTitle");
+
+    // Title should be updated from "JavaScript" to "JavaScript Test"
+    QTest::newRow("Test JS enabled") << true << getTestFilePath("javascript.html") << "JavaScript Test";
+    // Title should _not_ be updated from "JavaScript" to "JavaScript Test"
+    QTest::newRow("Test JS disabled") << false << getTestFilePath("javascript.html") << "JavaScript";
+}
+
+void tst_QQuickWebView::settings_JS()
+{
+
+    QFETCH(bool, jsEnabled);
+    QFETCH(QUrl, testUrl);
+    QFETCH(QString, expectedTitle);
+
+    bool wasJsEnabled = webView()->settings()->javaScriptEnabled();
+    webView()->settings()->setJavaScriptEnabled(jsEnabled);
+    webView()->setUrl(testUrl);
+    QVERIFY(waitForLoadSucceeded(webView()));
+    QTRY_COMPARE(webView()->title(), expectedTitle);
+    webView()->settings()->setJavaScriptEnabled(wasJsEnabled);
+}
+
 QTEST_MAIN(tst_QQuickWebView)
 #include "tst_qquickwebview.moc"
